# Benchmark

Lightweight benchmarking of the various models in terms of function and scalability. More comprehensive benchmarking with the state-of-the-art was performed in [our paper](https://www.biorxiv.org/content/10.1101/2023.07.21.549899v1).
